@@ -21,7 +21,7 @@ def get_binance_api_keys() -> BinanceApiKeys:
     env = os.getenv('JBG_ENV')
     file_path='/Users/jgardner/Documents/personal/.binance_api_keys'
     if env=='EC2':
-        file_path='~/.bnb_api_keys'
+        file_path='/home/ec2-user/.bnb_api_keys'
     d = fu.get_obj_from_file(file_path)
     dc = DataConverter()
     keys = dc.get_instance_from_dict(d,BinanceApiKeys)
